@@ -7,7 +7,7 @@ use OpenAPI::Client::OpenAI;
 use Archive::Zip;
 use XML::Twig;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub get_one_answer_from_new_llm {
     my ($request, $body_builder) = @_;
@@ -184,7 +184,7 @@ sub generate_meta_hashref_from_file{
         my $template_href = $json->decode($llm_answer_raw);
 
         # Business::LetterWriter::out_parts($template_href, {outfn => "TAILORED_VERSION.txt"});
-        my $metha_file_path_name = "./bj_applications/Elpro/META.txt";
+        my $metha_file_path_name = "./Customers/MyCustomer/META.txt";
         my $address_hashref = Business::LetterWriter::generate_meta_hashref_from_file($metha_file_path_name);
         my %combined_hash = ( %{$address_hashref} , %{$template_href});
 
